==> segatex-7.980.tar.gz: segatex-7.980/admin/cleanup_program/main.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2013 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <QtGui>
#include <iostream>

int main(int argc, char *argv[])
{
	QApplication app(argc,argv);

	//set current directory  
	QDir::setCurrent("./");
	//set file to be read
	QFile file;
	file.setFileName("target_domain_sqlite_final2.txt");
	//set file to be written 
	//QFile* file2 = new QFile();
	QFile file2;
	file2.setFileName("target_domain_sqlite_final3.txt");
	//set string
	QString str_echo_pre;
	QString str_echo,str_echo_final;
	QString str_echo_ready;
	QStringList str_echo_list,str_echo_list_rev,str_echo_list_rev_pre,str_echo_list_rev_pre2;
	QStringList str_echo_list_ready;
	QStringList s6_list;
	str_echo_list.clear();
	str_echo_list_rev.clear();
	str_echo_list_rev_pre.clear();
	str_echo_list_rev_pre2.clear();
	if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
		return 1;
	QTextStream in(&file);
	QString s0;
	QString s1,s1_pre;
	QString s2,s2_pre;
	QString s3,s3_pre;
	QString s4,s4_pre;
	QString s5,s5_pre;
	QString s6,s6_pre,s6_save,s6_echo;
	QString str_base;
	QString str_base_s5;
	QString str_flush;
	QString str_tmp;

	//str_echo_pre = in.readLine();
	str_echo_pre = "start";
	int check;
	check=0;
	while(!str_echo_pre.isNull()){
		str_tmp="";
		str_echo_pre = in.readLine();
		s0 = str_echo_pre.section(',', 0, 0);
		s1 = str_echo_pre.section(',', 1, 1);
		s2 = str_echo_pre.section(',', 2, 2);
		s3 = str_echo_pre.section(',', 3, 3);
		s4 = str_echo_pre.section(',', 4, 4);
		s5 = str_echo_pre.section(',', 5, 5);
		s6 = str_echo_pre.section(',', 6, 6);
		str_base = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5 + "," + s6;
		str_base_s5 = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5;
		///for debug
		//str_echo_list << s5;
		///end for debug
		if(s1_pre == s1 && s2_pre == s2 && s3_pre == s3 && s4_pre == s4 && s5_pre == s5){
			s6_save = s6_save + s6_pre + " " + s6;
			s6_list = s6_save.split(" ",QString::SkipEmptyParts);
			s6_list.removeDuplicates();
			s6_echo = s6_list.join(" ");
			//str_echo_list << s0 + "," + str_base_s5 + ", " + s6_echo;
			str_echo_list << str_tmp.setNum(check) << "," << s0 + "," + str_base_s5 + ", " + s6_echo;
		}else{
			//str_echo_list << s0 + "," + str_base;
			str_echo_list << str_tmp.setNum(check) << "," << s0 + "," + str_base;
			s6_save="";
			s6_echo="";
		}
		s1_pre = s1;
		s2_pre = s2;
		s3_pre = s3;
		s4_pre = s4;
		s5_pre = s5;
		s6_pre = s6;
		s6_pre = s6_pre.remove(QChar(','));
		//for debug
		//str_echo_list_rev_pre2 << str_echo_pre;
		//end for debug
		check++;
	}
	s0="",s1="",s2="",s3="",s4="",s5="",s6="";
	s1_pre="",s2_pre="",s3_pre="",s4_pre="",s5_pre="",s6_pre="";
	str_base="",str_base_s5="";
	s6_echo="";
	file.close();
	///////first
	int str_echo_list_size = str_echo_list.size();
	for(int i=str_echo_list_size; i >0; --i){
		str_echo = str_echo_list.value(i);
		s0 = str_echo.section(',', 0, 0);
		s1 = str_echo.section(',', 1, 1);
		s2 = str_echo.section(',', 2, 2);
		s3 = str_echo.section(',', 3, 3);
		s4 = str_echo.section(',', 4, 4);
		s5 = str_echo.section(',', 5, 5);
		s6 = str_echo.section(',', 6, 6);
		str_base = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5 + "," + s6;
		////for debug
		//str_echo_list_rev << s0;
		////end for debug
		if(s1_pre == s1 && s2_pre == s2 && s3_pre == s3 && s4_pre == s4 && s5_pre == s5){
			//
		}else{
			str_echo_list_rev << s0 + "," + str_base;
		}
		s1_pre = s1;
		s2_pre = s2;
		s3_pre = s3;
		s4_pre = s4;
		s5_pre = s5;
		s6_pre = s6;
		s6_pre = s6_pre.remove(QChar(','));
	}
	///////second
	int str_echo_list_rev_size = str_echo_list_rev.size();
	for(int i=0; i < str_echo_list_rev_size; ++i){
		str_echo = str_echo_list_rev.value(i);
		s0 = str_echo.section(',', 0, 0);
		s1 = str_echo.section(',', 1, 1);
		s2 = str_echo.section(',', 2, 2);
		s3 = str_echo.section(',', 3, 3);
		s4 = str_echo.section(',', 4, 4);
		s5 = str_echo.section(',', 5, 5);
		s6 = str_echo.section(',', 6, 6);
		str_base = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5 + "," + s6;
		if(s1_pre == s1 && s2_pre == s2 && s3_pre == s3 && s4_pre == s4 && s5_pre == s5){
			//
		}else{
			str_echo_list_rev_pre << s0 + "," + str_base;
		}
		s1_pre = s1;
		s2_pre = s2;
		s3_pre = s3;
		s4_pre = s4;
		s5_pre = s5;
		s6_pre = s6;
		s6_pre = s6_pre.remove(QChar(','));
	}
	QTextEdit* edit = new QTextEdit();
	edit->setFixedSize(1000,500);
	int str_echo_list_rev_pre_size = str_echo_list_rev_pre.size();
	int i,i2;
	//for(i=str_echo_list_rev_pre_size,i2=0;i>0,i2<str_echo_list_rev_pre_size;--i,++i2){
	for(i=str_echo_list_rev_pre_size;i>0;i--){
		str_echo_final = str_echo_list_rev_pre.value(i);
		std::cout << str_echo_final.toUtf8().constData() << std::endl;
		edit->setPlainText(str_echo_final);
	}

	if (!file2.open(QIODevice::WriteOnly | QIODevice::Text))
		return 1;
	QTextStream out(&file2);
	for(i2=str_echo_list_rev_pre_size;i2>0;i2--){
		out << str_echo_list_rev_pre.value(i2) << '\n';
	}

	edit->setWindowTitle("QFile Open&Read File");
	edit->show();
    
	return app.exec();
}

==> segatex-8.630.tar.gz: segatex-8.630/admin/cleanup_program/main.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2013 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <QtGui>
#include <iostream>

int main(int argc, char *argv[])
{
	QApplication app(argc,argv);

	//set current directory  
	QDir::setCurrent("./");
	//set file to be read
	QFile file;
	file.setFileName("target_domain_sqlite_final2.txt");
	//set file to be written 
	//QFile* file2 = new QFile();
	QFile file2;
	file2.setFileName("target_domain_sqlite_final3.txt");
	//set string
	QString str_echo_pre;
	QString str_echo,str_echo_final;
	QString str_echo_ready;
	QStringList str_echo_list,str_echo_list_rev,str_echo_list_rev_pre,str_echo_list_rev_pre2;
	QStringList str_echo_list_ready;
	QStringList s6_list;
	str_echo_list.clear();
	str_echo_list_rev.clear();
	str_echo_list_rev_pre.clear();
	str_echo_list_rev_pre2.clear();
	if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
		return 1;
	QTextStream in(&file);
	QString s0;
	QString s1,s1_pre;
	QString s2,s2_pre;
	QString s3,s3_pre;
	QString s4,s4_pre;
	QString s5,s5_pre;
	QString s6,s6_pre,s6_save,s6_echo;
	QString str_base;
	QString str_base_s5;
	QString str_flush;
	QString str_tmp;

	//str_echo_pre = in.readLine();
	str_echo_pre = "start";
	int check;
	check=0;
	while(!str_echo_pre.isNull()){
		str_tmp="";
		str_echo_pre = in.readLine();
		s0 = str_echo_pre.section(',', 0, 0);
		s1 = str_echo_pre.section(',', 1, 1);
		s2 = str_echo_pre.section(',', 2, 2);
		s3 = str_echo_pre.section(',', 3, 3);
		s4 = str_echo_pre.section(',', 4, 4);
		s5 = str_echo_pre.section(',', 5, 5);
		s6 = str_echo_pre.section(',', 6, 6);
		str_base = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5 + "," + s6;
		str_base_s5 = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5;
		///for debug
		//str_echo_list << s5;
		///end for debug
		if(s1_pre == s1 && s2_pre == s2 && s3_pre == s3 && s4_pre == s4 && s5_pre == s5){
			s6_save = s6_save + s6_pre + " " + s6;
			s6_list = s6_save.split(" ",QString::SkipEmptyParts);
			s6_list.removeDuplicates();
			s6_echo = s6_list.join(" ");
			//str_echo_list << s0 + "," + str_base_s5 + ", " + s6_echo;
			str_echo_list << str_tmp.setNum(check) << "," << s0 + "," + str_base_s5 + ", " + s6_echo;
		}else{
			//str_echo_list << s0 + "," + str_base;
			str_echo_list << str_tmp.setNum(check) << "," << s0 + "," + str_base;
			s6_save="";
			s6_echo="";
		}
		s1_pre = s1;
		s2_pre = s2;
		s3_pre = s3;
		s4_pre = s4;
		s5_pre = s5;
		s6_pre = s6;
		s6_pre = s6_pre.remove(QChar(','));
		//for debug
		//str_echo_list_rev_pre2 << str_echo_pre;
		//end for debug
		check++;
	}
	s0="",s1="",s2="",s3="",s4="",s5="",s6="";
	s1_pre="",s2_pre="",s3_pre="",s4_pre="",s5_pre="",s6_pre="";
	str_base="",str_base_s5="";
	s6_echo="";
	file.close();
	///////first
	int str_echo_list_size = str_echo_list.size();
	for(int i=str_echo_list_size; i >0; --i){
		str_echo = str_echo_list.value(i);
		s0 = str_echo.section(',', 0, 0);
		s1 = str_echo.section(',', 1, 1);
		s2 = str_echo.section(',', 2, 2);
		s3 = str_echo.section(',', 3, 3);
		s4 = str_echo.section(',', 4, 4);
		s5 = str_echo.section(',', 5, 5);
		s6 = str_echo.section(',', 6, 6);
		str_base = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5 + "," + s6;
		////for debug
		//str_echo_list_rev << s0;
		////end for debug
		if(s1_pre == s1 && s2_pre == s2 && s3_pre == s3 && s4_pre == s4 && s5_pre == s5){
			//
		}else{
			str_echo_list_rev << s0 + "," + str_base;
		}
		s1_pre = s1;
		s2_pre = s2;
		s3_pre = s3;
		s4_pre = s4;
		s5_pre = s5;
		s6_pre = s6;
		s6_pre = s6_pre.remove(QChar(','));
	}
	///////second
	int str_echo_list_rev_size = str_echo_list_rev.size();
	for(int i=0; i < str_echo_list_rev_size; ++i){
		str_echo = str_echo_list_rev.value(i);
		s0 = str_echo.section(',', 0, 0);
		s1 = str_echo.section(',', 1, 1);
		s2 = str_echo.section(',', 2, 2);
		s3 = str_echo.section(',', 3, 3);
		s4 = str_echo.section(',', 4, 4);
		s5 = str_echo.section(',', 5, 5);
		s6 = str_echo.section(',', 6, 6);
		str_base = s1 + "," + s2 + "," + s3 + "," + s4 + "," + s5 + "," + s6;
		if(s1_pre == s1 && s2_pre == s2 && s3_pre == s3 && s4_pre == s4 && s5_pre == s5){
			//
		}else{
			str_echo_list_rev_pre << s0 + "," + str_base;
		}
		s1_pre = s1;
		s2_pre = s2;
		s3_pre = s3;
		s4_pre = s4;
		s5_pre = s5;
		s6_pre = s6;
		s6_pre = s6_pre.remove(QChar(','));
	}
	QTextEdit* edit = new QTextEdit();
	edit->setFixedSize(1000,500);
	int str_echo_list_rev_pre_size = str_echo_list_rev_pre.size();
	int i,i2;
	//for(i=str_echo_list_rev_pre_size,i2=0;i>0,i2<str_echo_list_rev_pre_size;--i,++i2){
	for(i=str_echo_list_rev_pre_size;i>0;i--){
		str_echo_final = str_echo_list_rev_pre.value(i);
		std::cout << str_echo_final.toUtf8().constData() << std::endl;
		edit->setPlainText(str_echo_final);
	}

	if (!file2.open(QIODevice::WriteOnly | QIODevice::Text))
		return 1;
	QTextStream out(&file2);
	for(i2=str_echo_list_rev_pre_size;i2>0;i2--){
		out << str_echo_list_rev_pre.value(i2) << 'n';
	}

	edit->setWindowTitle("QFile Open&Read File");
	edit->show();
    
	return app.exec();
}
